/*
 * QUSOFT MICROSYSTMES
 * Moka
 * Copyright 2004 Frdric Brown
 */

/*
 *  This file is part of Moka API.
 *
 *  Moka API is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Moka API is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Moka API; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package moka.lang;

import moka.lang.Object;
import moka.lang.String;

/**
 * The Integer class wraps a value of the primitive type <code>int</code>
 * in an object. An object of type <code>Integer</code> contains a
 * single field whose type is <code>uint</code>.
 * <p>
 * In addition, this class provides several methods for converting
 * an <code>uint</code> to a <code>String</code> and a
 * <code>String</code> to an <code>uint</code>, as well as other
 * constants and methods useful when dealing with an
 * <code>uint</code>.
 * <p>
 *
 * @author  Frdric Brown
 * @version 1.0, 2004-03-13
 * @since   MDK2.2
 */
public class UInteger extends moka.lang.Object {

	/**
	* The smallest value of type <code>uint</code>. The constant
	* value of this field is <tt>0</tt>.
	*/
	public static final int   MIN_VALUE = 0;

	/**
	* The largest value of type <code>int</code>. The constant
	* value of this field is <tt>4294967295</tt>.
	*/
	public static final int   MAX_VALUE = 0xffffffff;

	/**
	* The value of the UInteger.
	*/
	private uint value;

    /**
     * Constructs a newly allocated <code>UInteger</code> object that
     * represents the primitive <code>uint</code> argument.
     *
     * @param   value   the value to be represented by the <code>UInteger</code>.
     */
    public UInteger (uint value) {
		this.value = value;
    }

    /**
     * Constructs a newly allocated <code>UInteger</code> object that
     * represents the value represented by the string. The string is
     * converted to an <tt>uint</tt> in exactly the manner used by the
     * <tt>parseUint</tt> method.
     *
     * @param      s   the <code>String</code> to be converted to an
     *                 <code>UInteger</code>.
     */
    public UInteger (String s) {
		this.value = 0;
    }

    /**
     * Returns a <code>String</code> object representing this
     * <code>UInteger</code>'s value. The value is converted to signed
     * decimal representation and returned as a string, exactly as if
     * the integer value were given as an argument to the valueOf method
     * of String.
     *
     * @return  a string representation of the value of this object.
     */
    public String toString () {
    	return String.valueOf(this.value);
    }

    /**
     * Compares this object to the specified object.  The result is
     * <code>true</code> if and only if the argument is not
     * <code>null</code> and is an <code>UInteger</code> object that
     * contains the same <code>uint</code> value as this object.
     *
     * @param   obj   the object to compare with.
     * @return  <code>true</code> if the objects are the same;
     *          <code>false</code> otherwise.
     */
    public boolean equals (Object obj) {
		if (obj instanceof UInteger) {
			return this.value == ((UInteger)obj).value;
		}
		return false;
    }

    /**
     * Returns the value of this <code>UInteger</code> as an
     * <code>uint</code>.
     */
    public uint uintValue() {
		return this.value;
    }

    /**
     * Returns the value of this <code>UInteger</code> as an
     * <code>int</code>.
     */
    public int intValue() {
		return (int)this.value;
    }

    /**
     * Parses the string argument as a signed decimal integer. The
     * characters in the string must all be decimal digits. The resulting
     * integer value is returned.  The string argument is finalized before the method
     * returns.
     *
     * @param s	   a <code>String</code> containing the <code>uint</code>
     *             representation to be parsed
     * @return     the integer value represented by the argument in decimal.
     */
    public native static int parseUint (String s) ;

    /**
     * Returns the value of this UInteger as a <code>long</code>.
     * This may involve rounding or truncation.
     *
     * @return  the numeric value represented by this object after conversion
     *          to type <code>long</code>.
     */
    public long longValue () {
    	return (long)this.value;
    }

    /**
     * Returns the value of this UInteger as a <code>double</code>.
     * This may involve rounding.
     *
     * @return  the numeric value represented by this object after conversion
     *          to type <code>double</code>.
     */
    public double doubleValue () {
    	return (double)this.value;
    }

    /**
     * Returns the value of this UInteger as a <code>byte</code>.
     * This may involve rounding or truncation.
     *
     * @return  the numeric value represented by this object after conversion
     *          to type <code>byte</code>.
     */
    public byte byteValue () {
    	return (byte)this.value;
    }

    /**
     * Returns the value of this UInteger as a <code>short</code>.
     * This may involve rounding or truncation.
     *
     * @return  the numeric value represented by this object after conversion
     *          to type <code>short</code>.
     */
    public short shortValue() {
    	return (short)this.value;
    }

    /**
     * Checks if the specified string is a decimal representation
     * of an usigned integer.
     *
     * @param str The string to verify
     * @return true if the specified string is a decimal representation of an integer, false otherwize.
     */
    public static boolean isUint (String str) {

    	return true;
    }
}